@@ -4,7 +4,7 @@ from mindsdb_sql.parser.ast import *
 from mindsdb_sql.exceptions import ParsingException
 from mindsdb_sql.parser.lexer import SQLLexer
 from mindsdb_sql.parser.logger import ParserLogger
-from mindsdb_sql.utils import ensure_select_keyword_order, JoinType
+from mindsdb_sql.parser.utils import ensure_select_keyword_order, JoinType
 
 
 class SQLParser(Parser):
